Struct libp2p_swarm::ConnectionCounters
source · [−]pub struct ConnectionCounters { /* private fields */ }Expand description
Network connection information.
Implementations
sourceimpl ConnectionCounters
impl ConnectionCounters
sourcepub fn limits(&self) -> &ConnectionLimits
pub fn limits(&self) -> &ConnectionLimits
The effective connection limits.
sourcepub fn num_connections(&self) -> u32
pub fn num_connections(&self) -> u32
The total number of connections, both pending and established.
sourcepub fn num_pending(&self) -> u32
pub fn num_pending(&self) -> u32
The total number of pending connections, both incoming and outgoing.
sourcepub fn num_pending_incoming(&self) -> u32
pub fn num_pending_incoming(&self) -> u32
The number of incoming connections being established.
sourcepub fn num_pending_outgoing(&self) -> u32
pub fn num_pending_outgoing(&self) -> u32
The number of outgoing connections being established.
sourcepub fn num_established_incoming(&self) -> u32
pub fn num_established_incoming(&self) -> u32
The number of established incoming connections.
sourcepub fn num_established_outgoing(&self) -> u32
pub fn num_established_outgoing(&self) -> u32
The number of established outgoing connections.
sourcepub fn num_established(&self) -> u32
pub fn num_established(&self) -> u32
The total number of established connections.